## `raggy`

```python
pip install raggy
```

Read the [docs](https://zzstoatzz.github.io/raggy/)

### examples
- scraping the web to produce rich documents
- putting these documents in vectorstores
- querying the vectorstores to find documents similar to a query

see this [example](https://github.com/zzstoatzz/raggy/blob/main/examples/refresh_tpuf/refresh_namespace.py) I use to refresh a chatbot that knows about `prefect`.
